summaryrefslogtreecommitdiffstats
path: root/tdecore/kmimesourcefactory.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
commitb19ddece21e102b8e4b292037ca7578f60b128fe (patch)
tree6572ca25aba80849cdfa7578bbbc9121d23afbc3 /tdecore/kmimesourcefactory.h
parente729c6d549f12e27b358a1dad04ff254c033ac71 (diff)
downloadtdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.tar.gz
tdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kmimesourcefactory.h')
-rw-r--r--tdecore/kmimesourcefactory.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdecore/kmimesourcefactory.h b/tdecore/kmimesourcefactory.h
index 2ee6728e6..7090b1733 100644
--- a/tdecore/kmimesourcefactory.h
+++ b/tdecore/kmimesourcefactory.h
@@ -26,7 +26,7 @@
#include <kglobal.h>
class KMimeSourceFactoryPrivate;
-class KInstance;
+class TDEInstance;
/**
* An extension to TQMimeSourceFactory that uses KIconLoader to
@@ -74,10 +74,10 @@ protected:
private:
/**
* @internal
* Associate with a KInstance so we can pull its iconLoader() when need arises.
*/
- friend class KInstance;
- void setInstance(KInstance *);
+ friend class TDEInstance;
+ void setInstance(TDEInstance *);
KMimeSourceFactoryPrivate* d;
};
@@ -74,10 +74,10 @@ protected:
/**
* @internal
- * Associate with a KInstance so we can pull its iconLoader() when need arises.
+ * Associate with a TDEInstance so we can pull its iconLoader() when need arises.
*/